# Simple Ajax Views for Django

Django AjaxView provides a simple super-class to quickly graft ajax functionality on any page.

By [Ken Kinder](https://kkinder.com/)

* [Installation Instructions](installation.md)
* [Usage Guide](usage.md)
* [Changelog](changelog.md)